ChiantiPy\.core package
=======================

Subpackages
-----------

.. toctree::

    ChiantiPy.core.tests

Submodules
----------

ChiantiPy\.core\.Continuum module
---------------------------------

.. automodule:: ChiantiPy.core.Continuum
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.Ion module
---------------------------

.. automodule:: ChiantiPy.core.Ion
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.Ioneq module
-----------------------------

.. automodule:: ChiantiPy.core.Ioneq
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.IpyMspectrum module
------------------------------------

.. automodule:: ChiantiPy.core.IpyMspectrum
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.Mspectrum module
---------------------------------

.. automodule:: ChiantiPy.core.Mspectrum
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.RadLoss module
-------------------------------

.. automodule:: ChiantiPy.core.RadLoss
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.MradLoss module
--------------------------------

.. automodule:: ChiantiPy.core.MradLoss
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.Bunch module
--------------------------------

.. automodule:: ChiantiPy.core.Bunch
    :members:
    :undoc-members:
    :show-inheritance:

ChiantiPy\.core\.Spectrum module
--------------------------------

.. automodule:: ChiantiPy.core.Spectrum
    :members:
    :undoc-members:
    :show-inheritance:

Module contents
---------------

.. automodule:: ChiantiPy.core
    :members:
    :undoc-members:
    :show-inheritance:
